#
# spec file for package primesieve
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           primesieve
Version:        12.4
Release:        1.1
Summary:        A prime number generator
License:        BSD-2-Clause
Group:          Development/Libraries/C and C++
URL:            https://github.com/kimwalisch/primesieve
Source0:        https://github.com/kimwalisch/primesieve/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake >= 3.7
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  asciidoc
BuildRequires:  pkgconfig

%description
primesieve is a command-line program that generates primes using the
sieve of Eratosthenes algorithm. It can generate primes and prime
k-tuplets (twin primes, prime triplets, ...) up to 2^64 and find the
nth prime.

%package -n libprimesieve12
Summary:        C/C++ library for generating prime numbers

%description -n libprimesieve12
This package contains the shared runtime library for primesieve.

%package -n libprimesieve-devel
Summary:        Development files for the primesieve library
Requires:       libprimesieve12 = %{version}

%description -n libprimesieve-devel
This package contains the C/C++ header files and the configuration
files for developing applications that use the primesieve library.
It also contains the API documentation of the library.

%prep
%setup -q

%build
%cmake -DBUILD_MANPAGE=ON \
       -DBUILD_TESTS=ON \
       -DCMAKE_SKIP_RPATH:BOOL=OFF
%cmake_build

%install
%cmake_install
%fdupes %{buildroot}/%{_prefix}

%post -n libprimesieve12 -p /sbin/ldconfig
%postun -n libprimesieve12 -p /sbin/ldconfig

%check
%ctest

%files -n primesieve
%doc README.md ChangeLog
%{_bindir}/primesieve
%{_mandir}/man1/primesieve.1%{?ext_man}

%files -n libprimesieve12
%license COPYING
%{_libdir}/libprimesieve.so.*

%files -n libprimesieve-devel
%doc doc/C_API.md doc/CPP_API.md
%{_libdir}/libprimesieve.so
%{_includedir}/primesieve.h
%{_includedir}/primesieve.hpp
%dir %{_includedir}/primesieve
%{_includedir}/primesieve/StorePrimes.hpp
%{_includedir}/primesieve/iterator.h
%{_includedir}/primesieve/iterator.hpp
%{_includedir}/primesieve/primesieve_error.hpp
%dir %{_libdir}/cmake/primesieve
%{_libdir}/cmake/primesieve/*.cmake
%{_libdir}/pkgconfig/primesieve.pc

%changelog
* Thu Aug  1 2024 Kim Walisch <kim.walisch@gmail.com>
- Update to primesieve-12.4
- Move x86 CPUID code from cpuid.hpp to src/x86/cpuid.cpp
- multiarch_x86_popcnt.cmake: Detect x86 POPCNT support
- CMakeLists.txt: Use CMake list for all compile time definitions
- CMakeLists.txt: Use CMake list for all link libraries
* Wed Apr 17 2024 Kim Walisch <kim.walisch@gmail.com>
- Update to primesieve-12.3
- Add runtime POPCNT detection using CPUID for x86 CPUs
- Improve GCC/Clang multiarch preprocessor logic
- CMakeLists.txt: Remove POPCNT/BMI check for x86 CPUs
* Tue Mar 12 2024 Kim Walisch <kim.walisch@gmail.com>
- Update to primesieve-12.1
- CMakeLists.txt: Fix undefined reference to pthread_create
- Fix -ffast-math failure of --test option
- Fix musl libc issue in unit tests
- Improve status output
* Mon Feb 19 2024 Kim Walisch <kim.walisch@gmail.com>
- Update to primesieve-12.0
- New -S and --stress-test[=MODE] command-line options.
- New --timeout=SECS option for stress testing.
- New -R && --RiemannR command line options.
- New --RiemannR-inverse command line option.
- Faster Riemann R function implementation.
- Improve command-line option handling.
* Thu Jan 11 2024 Kim Walisch <kim.walisch@gmail.com>
- Update to primesieve-11.2
- Fix CMake libatomic detection
- Improved nth prime algorithm
- Fix off by 1 error in OpenMP example in C_API.md
- Fix off by 1 error in OpenMP example in CPP_API.md
* Sat May 13 2023 Kim Walisch <kim.walisch@gmail.com>
- Update to primesieve-11.1
- Vectorized pre-sieving algorithm using x64 SSE2 and ARM NEON
- Added POPCNT algorithm for x64 & AArch64
- Fix -Wstrict-prototypes warnings
* Wed Dec  7 2022 Kim Walisch <kim.walisch@gmail.com>
- Update to primesieve-11.0
- primesieve version now match libprimesieve version (.so version)
- Added new primesieve::iterator::jump_to() method (C++ API)
- Added new primesieve_jump_to() function (C API)
- Mark primesieve_skipto() as deprecated
- Fix use after free in primesieve::iterator::clear()
- Fix use after free in primesieve_iterator_clear()
- Fix potential memory leak in malloc_vector.hpp
* Thu Jul  7 2022 Kim Walisch <kim.walisch@gmail.com>
- Update to primesieve-8.0
- Added multiarch support (POPCNT, BMI2, AVX512) for x64 CPUs
- Generating an array (or vector) of primes is up to 20%% faster
- Main CMakeLists.txt has been split up into multiple modules
- Improved documentation of C & C++ APIs
* Tue May  3 2022 Kim Walisch <kim.walisch@gmail.com>
- Update to primesieve-7.9
- Reduced memory usage and faster initialization
- Reduced branch mispredictions by up to 30%%
- Improved nth prime approximation
- Increase max sieve array size to 8 KiB
* Sun Jan 30 2022 Kim Walisch <kim.walisch@gmail.com>
- Update to primesieve-7.8
- Improved pre-sieving, up to 10%% speedup
- Improved primesieve::iterator, up to 15%% speedup
- C++ refactoring: get rid of using namespace std
* Tue Dec  7 2021 Kim Walisch <kim.walisch@gmail.com>
- Fix issues with big.LITTLE CPUs e.g. Intel Alder Lake
- Improved C API error messages
- Improved C/C++ API documentation
* Fri Jan  8 2021 Kim Walisch <kim.walisch@gmail.com>
- Update to primesieve-7.6
* Mon Jan  6 2020 Kim Walisch <kim.walisch@gmail.com>
- Update to primesieve-7.5
* Wed May  1 2019 Jan Engelhardt <jengelh@inai.de>
- Trim subjective parts from description.
* Tue Apr 30 2019 Kim Walisch <kim.walisch@gmail.com>
- Fix review issues
- Fix rpmlint warnings
- Convert Fedora spec file to openSUSE format
